@@ -14,6 +14,7 @@ import numpy as np
 import os
 import sys
 
+from lcbuilder.HarmonicSelector import HarmonicSelector
 from lcbuilder.helper import LcbuilderHelper
 from lcbuilder.lcbuilder_class import LcBuilder
 from lcbuilder.curve_preparer.Flattener import Flattener
@@ -204,6 +205,10 @@ class Sherlock:
         for sherlock_target in self.sherlock_targets:
             self.__run_object(sherlock_target)
 
+    def __min_transits_count(self, lc_build, sherlock_target):
+        return sherlock_target.min_transits_count \
+                if sherlock_target.min_transits_count > 0 else lc_build.transits_min_count
+
     def __run_object(self, sherlock_target):
         """
         Performs the analysis for one object_info
@@ -220,10 +225,12 @@ class Sherlock:
             time = lc_build.lc.time.value
             flux = lc_build.lc.flux.value
             flux_err = lc_build.lc.flux_err.value
+            min_transits_count = self.__min_transits_count(lc_build, sherlock_target)
             period_grid, oversampling = LcbuilderHelper.calculate_period_grid(time, sherlock_target.period_min,
                                                                 sherlock_target.period_max,
                                                                 sherlock_target.oversampling,
-                                                                lc_build.star_info, lc_build.transits_min_count)
+                                                                lc_build.star_info,
+                                                                1)
             id_run = 1
             best_signal_score = 1
             self.report[sherlock_id] = []
@@ -255,7 +262,7 @@ class Sherlock:
                 logging.info("________________________________ run %s________________________________", id_run)
                 transit_results, signal_selection = \
                     self.__analyse(sherlock_target, time, lcs, flux_err, lc_build.star_info, id_run,
-                                   lc_build.transits_min_count, lc_build.cadence, self.report[sherlock_id], wl,
+                                   min_transits_count, lc_build.cadence, self.report[sherlock_id], wl,
                                    period_grid, lc_build.detrend_period)
                 all_nan_results = len(np.argwhere(~np.isnan(signal_selection.transit_result.t0s)).flatten()) == 0
                 if not all_nan_results:
@@ -358,6 +365,7 @@ class Sherlock:
     def __init_object_dir(self, object_id, clean_dir=False):
         dir = self.results_dir + str(object_id)
         dir = dir.replace(" ", "_")
+        dir = dir if not self.explore else dir + '_explore'
         if clean_dir:
             self.__remove_object_dir(object_id)
         if not os.path.exists(dir):
@@ -478,8 +486,9 @@ class Sherlock:
                 object_info.oscillation_max_period < object_info.oscillation_min_period:
             logging.info("Stellar oscillation period has been set to empty. Defaulting to 1/3 the minimum search period")
             object_info.oscillation_max_period = sherlock_target.period_min / 3
-        lc_build = self.lcbuilder.build(object_info, object_dir)
-        logging.info('Minimum number of transits: %s', lc_build.transits_min_count)
+        lc_build = self.lcbuilder.build(object_info, object_dir, cpus=sherlock_target.cpu_cores)
+        min_transits_count = self.__min_transits_count(lc_build, sherlock_target)
+        logging.info('Minimum number of transits: %s', min_transits_count)
         lightcurve_timespan = lc_build.lc.time[len(lc_build.lc.time) - 1] - lc_build.lc.time[0]
         if sherlock_target.search_zone is not None and not (lc_build.star_info.mass_assumed or
                                                             lc_build.star_info.radius_assumed):
@@ -745,18 +754,16 @@ class Sherlock:
         return transit_results
 
     def __find_matching_oi(self, object_info, period, epoch):
+        oi = ""
         if self.ois is not None:
             mission, mission_id, target_id = LcBuilder().parse_object_info(object_info.mission_id())
             corrected_epoch = LcbuilderHelper.normalize_mission_epoch(mission, epoch)
-            existing_period_in_object = self.ois[(self.ois["Object Id"] == object_info.mission_id()) &
-                                                 (0.99 < self.ois["Period (days)"] / period) &
-                                                 (self.ois["Period (days)"] / period < 1.01) &
-                                                 (np.abs(self.ois['Epoch (BJD)'] - corrected_epoch) % period < 0.05 * period)]
-            existing_period_in_oi = existing_period_in_object[existing_period_in_object["OI"].notnull()]
-            oi = existing_period_in_oi["OI"].iloc[0] if len(
-                existing_period_in_oi.index) > 0 else np.nan
-        else:
-            oi = ""
+            existing_period_in_object = self.ois[(self.ois["Object Id"] == object_info.mission_id())]
+            exists_oi = False
+            for index, row in existing_period_in_object.iterrows():
+                if HarmonicSelector.is_harmonic(0, (np.abs(corrected_epoch - row['Epoch (BJD)']) % period), period, row["Period (days)"]):
+                    oi = row["OI"]
+                    break
         return oi
 
     def __adjust_transit(self, sherlock_target, time, lc, star_info, transits_min_count, run_results, report, cadence,
